[MOBY-guts] biomoby commit

Paul Gordon gordonp at dev.open-bio.org
Fri Nov 14 15:53:20 UTC 2008


gordonp
Fri Nov 14 10:53:19 EST 2008
Update of /home/repository/moby/moby-live/Java/src/main/org/biomoby/shared/data
In directory dev.open-bio.org:/tmp/cvs-serv6182/src/main/org/biomoby/shared/data

Modified Files:
	MobyDataSecondaryInstance.java 
Log Message:
Made default value the value of a new secondary data instance
moby-live/Java/src/main/org/biomoby/shared/data MobyDataSecondaryInstance.java,1.10,1.11
===================================================================
RCS file: /home/repository/moby/moby-live/Java/src/main/org/biomoby/shared/data/MobyDataSecondaryInstance.java,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- /home/repository/moby/moby-live/Java/src/main/org/biomoby/shared/data/MobyDataSecondaryInstance.java	2007/12/06 16:44:04	1.10
+++ /home/repository/moby/moby-live/Java/src/main/org/biomoby/shared/data/MobyDataSecondaryInstance.java	2008/11/14 15:53:19	1.11
@@ -23,7 +23,7 @@
     }
 
     /**
      * Basically clones the input parameter
      */
     public MobyDataSecondaryInstance(MobySecondaryData type){
 	super(type.getName());
@@ -35,6 +35,7 @@
 	}
 	setAllowedValues(type.getAllowedValues());
 	setDefaultValue(type.getDefaultValue());
+	setValue(type.getDefaultValue());
 	setMinValue(type.getMinValue());
 	setMaxValue(type.getMaxValue());
 	setDescription(type.getDescription());
@@ -23,7 +23,7 @@
 
     /**
-     * Basically clones the input parameter
+     * Basically clones the input parameter, and sets the value to the default value.
      */
     public MobyDataSecondaryInstance(MobySecondaryData type){




More information about the MOBY-guts mailing list